@@ -6,7 +6,7 @@ use Regexp::Grammars;
 use Moo;
 use namespace::autoclean;
 
-our $VERSION = '0.008';    # VERSION
+our $VERSION = '0.009';    # VERSION
 
 # ABSTRACT: Parse DOS .bat and .cmd files
 
@@ -47,7 +47,7 @@ has 'grammar' => (
 
            <rule: Call> call <Token>
 
-           <rule: Goto> Goto <Identifier=LabelIdentifier>
+           <rule: Goto> Goto :?<Identifier=LabelIdentifier>
 
            <rule: Set> set <Variable=Token>=<Value=Token>
 
@@ -106,7 +106,7 @@ App::BatParser - Parse DOS .bat and .cmd files
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 DESCRIPTION
 
